// Package json_tool...
//
// Description : json_tool...
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 2021-03-10 11:44 下午
package json_tool

import (
	"encoding/json"
	"fmt"
	"testing"
)

// TestJSON ...
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 10:58 下午 2021/3/14
func TestJSON(t *testing.T) {
	tree := NewDynamicJSON()
	fmt.Println(tree.extraSliceIndex("[200]"))
	tree.SetValue("extra.height.value", 180, false)
	tree.SetValue("extra.height.unit.use", "cm", false)
	tree.SetValue("extra.height.unit.open", "1", false)
	tree.SetValue("name", "zhangdeman", false)
	tree.SetValue("good.name", "good", false)
	tree.SetValue("work", "111", false)
	tree.SetValue("good.price", "180", false)
	tree.SetValue("good.unit", "$", false)
	tree.SetValue("slice.[0].name", "zhang", false)
	tree.SetValue("slice.[0].age", 30, false)
	tree.SetValue("slice.[1].name", "de", false)
	tree.SetValue("slice.[2].name", "man", false)
	tree.SetValue("slice.[3]", "zhangdeman", false)
	fmt.Println(tree.String())
	tree = NewDynamicJSON()
	tree.SetValue("[0]", "zhang", false)
	tree.SetValue("[1]", "de", false)
	tree.SetValue("[2]", "man", false)
	fmt.Println(tree.String())
}

// TestSelect 测试动态选择字段
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 9:47 下午 2021/4/13
func TestSelect(t *testing.T) {
	source := map[string]interface{}{
		"name": "zhangdeman",
		"extra": map[string]interface{}{
			"age":    18,
			"height": 180,
			"slice":  []int{1, 2, 3},
		},
		"slice_data": []int{1, 2, 3},
		"map":        map[string]interface{}{"a": 1, "b": 2, "c": 4},
		"table": []map[string]interface{}{
			{"name": "alex", "age": 18, "number": 1},
			{"name": "bob", "age": 28, "number": 2},
			{"name": "bob", "age": 28, "number": 2, "list": []int{1, 2, 3}},
		},
	}
	rule := map[string]MapDataRule{
		"name":          {MapKey: "user_name", DefaultValue: "用户姓名默认值", IsComplexType: false},
		"extra.age":     {MapKey: "user_age", DefaultValue: "用户年龄默认值", IsComplexType: false},
		"extra.height":  {MapKey: "user_height", DefaultValue: "扩展高度默认值", IsComplexType: false},
		"table.[].name": {MapKey: "slice.[].name_modify", DefaultValue: "列表姓名默认值", IsComplexType: false},
		"table.[].list": {MapKey: "slice.[].data_list", DefaultValue: "[\"567\",\"678\",\"789\"]", IsComplexType: true},
	}
	filter := NewFilter(source, rule)
	d, e := filter.Result()
	if nil != e {
		fmt.Println(e)
		return
	}
	fmt.Println(d.String())
}

// TestParse 测试获取JSON数据结构
//
// Author : go_developer@163.com<张德满>
//
// Date : 10:59 PM 2022/1/9
func TestParse(t *testing.T) {
	source := map[string]interface{}{
		"name": "zhangdeman",
		"extra": map[string]interface{}{
			"age":    18,
			"height": 180,
			"slice":  []int{1, 2, 3},
			"obj": map[string]interface{}{
				"la": "aaaa",
			},
		},
		"slice": []int{1, 2, 3},
		"map":   map[string]interface{}{"a": 1, "b": 2, "c": 4},
		"table": []map[string]interface{}{
			{"name": "alex", "age": 18, "number": 1, "obj": map[string]interface{}{"enen": "en"}},
			{"name": "bob", "age": 28, "number": 2},
		},
		"two_slice": []map[string]interface{}{
			{
				"students": []map[string]interface{}{
					{
						"name":  "enen",
						"age":   18,
						"score": []float64{1, 2, 3, 45},
					},
				},
				"other":     []interface{}{"others"},
				"read_only": 1,
			},
		},
	}
	byteData, _ := json.Marshal(source)
	fmt.Println(GetJSONDataStruct(string(byteData)))
}
